// Load iCalendar data
function adjustHeight() {
  setTimeout(function() {
    var calendarHeight = document.getElementById('calendar').offsetHeight;
    window.parent.postMessage({ height: calendarHeight }, '*');
  }, 200); // wait for x milliseconds before measuring
}

window.addEventListener('message', function(event) {
  adjustHeight();
}, false);

async function fetchAndParseICS() {
  const response = await fetch('./data/calendar.ics');
  const data = await response.text();
  const jcalData = ICAL.parse(data);
  const comp = new ICAL.Component(jcalData);
  return comp.getAllSubcomponents('vevent');
}

fetchAndParseICS()
.then(vevents => {
  let calendarEvents = [];

  for (let vevent of vevents) {
    let summary = vevent.getFirstPropertyValue('summary');
    let description = vevent.getFirstPropertyValue('description');
    let dtstartIcal = vevent.getFirstPropertyValue('dtstart');
    let dtendIcal = vevent.getFirstPropertyValue('dtend');

    let dtstart = dtstartIcal ? dtstartIcal.toJSDate() : null;
    let dtend = dtendIcal ? dtendIcal.toJSDate() : null;

    if (summary.toLowerCase().includes('nutzung')) {  // Skip events with "Nutzung" in the title
      continue;
    }

    calendarEvents.push({
      title: summary,
      start: dtstart,
      end: dtend,
      description: description,
      allDay: dtstartIcal ? dtstartIcal.isDate : false
    });
  }

  // Determine the initial view based on screen width
  let isMobile = window.innerWidth <= 768;
  let initialViewType = isMobile ? 'listMonth' : 'dayGridMonth';

  var calendarEl = document.getElementById('calendar');
  var debounceTimer;
  var calendar = new FullCalendar.Calendar(calendarEl, {
    locale: 'de', // German locale
    initialView: initialViewType,
    headerToolbar: {
      left: 'prev,next today',
      center: 'title',
      right: 'dayGridMonth,listMonth'
    },
    views: {
      dayGridMonth: { buttonText: 'Kalender'},
      listMonth: { buttonText: 'Liste' },
    },
    contentHeight: "auto",
    events: calendarEvents,
    eventDisplay: 'block',
    eventContent: function(arg) {
      var start = arg.event.start;
      var end = arg.event.end;
      var title = arg.event.title;
      
      // Format time as "[start time] - [end time] Uhr: [title]"
      var startTime = start.getHours() + ':' + (start.getMinutes()<10?'0':'') + start.getMinutes();
      var endTime = end.getHours() + ':' + (end.getMinutes()<10?'0':'') + end.getMinutes();
      var formattedTime = startTime + ' - ' + endTime + ' Uhr: ';
      
      var tooltipContent = formattedTime + title;
    
      return {
        html: `<div title="${tooltipContent}">${title}</div>`
      }
    },
    eventDidMount: function(info) {
      clearTimeout(debounceTimer);
      debounceTimer = setTimeout(adjustHeight, 200);
    },
    eventWillUnmount: function() {
        clearTimeout(debounceTimer);
        debounceTimer = setTimeout(adjustHeight, 200);
    },
    allDaySlot: false, // Remove the "all-day" section from the calendar
    slotMinTime: '07:00:00', // Beginning at 7am
    slotMaxTime: '20:00:00', // Ending at 8pm
  });

  calendar.render();

  adjustHeight();
});
